@@ -60,10 +60,13 @@ def extract_zip(filename, chrome_maj_version):
 
 
 def setup_selenium(options, chrome_binary_path):
-    # Configures selenium to use a custom path
-    driver_path = get_webdriver(chrome_binary_path)
-
-    return webdriver.Chrome(executable_path=driver_path, options=options)
+    try:
+        # try letting Selenium find the driver (in PATH)
+        return webdriver.Chrome(options=options)
+    except WebDriverException:
+        # Configures selenium to use a custom path
+        driver_path = get_webdriver(chrome_binary_path)
+        return webdriver.Chrome(executable_path=driver_path, options=options)
 
 def parse_version(output):
     """
@@ -75,7 +78,7 @@ def get_chrome_version(chrome_binary_path=None):
     """
     Extract the chrome major version.
     """
-    driver_locations = [which(loc) for loc in ["google-chrome", "google-chrome-stable", "chromium", "chrome.exe"]]
+    driver_locations = [which(loc) for loc in ["google-chrome", "google-chrome-stable", "chromium", "chromium-browser", "chrome.exe"]]
 
     for location in driver_locations:
         if location:
